# shipgrav
[![build status](https://github.com/PFPE/shipgrav/workflows/tests/badge.svg)](https://github.com/PFPE/shipgrav/actions)

shipgrav is a Python package designed for reading, processing, and reducing marine gravity data from UNOLS ships. It is created and maintained by PFPE for the marine gravimetry community. The shipgrav repository also contains scripts with example workflows for gravity data processing and reduction.

## Dependencies
python 3.9+\
numpy\
scipy\
pandas 2.0+\
statsmodels\
tomli\
pyyaml

To run the example scripts, you will also need matplotlib.

## Installation
shipgrav can be installed from PyPI using `pip`. Detailed instructions are in the [documentation](https://shipgrav.readthedocs.io/).

## Documentation and usage
The shipgrav documentation is available online at [shipgrav.readthedocs.io](https://shipgrav.readthedocs.io/). It can also be accessed offline by building the contents of the `docs` folder using sphinx.

## Contributing to shipgrav
Please do! If you have ideas for how to make shipgrav better, you can raise an issue on github or contact PFPE.
